﻿using Leadtools.Multimedia;
using System;
using System.Windows.Forms;

namespace MotionDetectionWithDVR
{
   public partial class MainForm : Form
   {
      public LMVMtnDetLib.ILMVMtnDet motion;
      public MtnDtCallback mtnCllbck;
      public string DVRfilePath = @"sample.LBL";
      public CaptureCtrl captureCtrl1;
      public MainForm()
      {
         try
         {
            InitializeComponent();
            captureCtrl1 = new CaptureCtrl();
            captureCtrl1.Dock = DockStyle.Fill;
            panel1.Controls.Add(captureCtrl1);
            captureCtrl1.Preview = true;
            captureCtrl1.PreviewSource = CapturePreview.VideoAndAudio;
         }
         catch (Exception ex)
         {
            MessageBox.Show(ex.Message);
         }
      }

      private void MainForm_Load(object sender, EventArgs e)
      {
         ToolTip tooltip = new ToolTip();
         tooltip.AutoPopDelay = 5000;
         tooltip.InitialDelay = 500;
         tooltip.ReshowDelay = 500;
         tooltip.ShowAlways = true;

         tooltip.SetToolTip(_lblMinStillTime, "The minimum length of still periods (in milliseconds).\nA still period of at least this length is required before motion is considered stopped. All periods without movement shorter than the minimum still time will be considered still part of the motion.\nYou use this to keep short periods of inactivity as part of the motion The allowed range is 0..1000000 ms(equivalent to 0..1000 sec)");
         tooltip.SetToolTip(_tbMinStillTime, "The minimum length of still periods (in milliseconds).\nA still period of at least this length is required before motion is considered stopped. All periods without movement shorter than the minimum still time will be considered still part of the motion.\nYou use this to keep short periods of inactivity as part of the motion The allowed range is 0..1000000 ms(equivalent to 0..1000 sec)");
         tooltip.SetToolTip(_lblInterval, "Set the time in milli seconds of the delay time between checks for motion.");
         tooltip.SetToolTip(_tbInterval, "Set the time in milli seconds of the delay time between checks for motion.");
         tooltip.SetToolTip(_lblSensitivity, "Set the Motion sensitivity. A small value specifies high detection sensitivity (smaller changes will trigger the callback). A large value specifies low detection sensitivity (and bigger changes are needed to trigger the callback).");
         tooltip.SetToolTip(_tbSensitivity, "Set the Motion sensitivity. A small value specifies high detection sensitivity (smaller changes will trigger the callback). A large value specifies low detection sensitivity (and bigger changes are needed to trigger the callback).");

         if (!Get_devices())
         {
            MessageBox.Show("No video or audio devices detected!");
            Close();
         }
      }

      private bool Get_devices()
      {
         try
         {
            if (captureCtrl1.VideoDevices.Count > 0)
            {
               foreach (Device device in captureCtrl1.VideoDevices)
               {
                  _cbVideoDevices.Items.Add(device.FriendlyName);
               }
               _cbVideoDevices.SelectedIndex = 0;

               foreach (Device device in captureCtrl1.AudioDevices)
               {
                  _cbAudioDevices.Items.Add(device.FriendlyName);
               }
               _cbAudioDevices.SelectedIndex = 0;

               return true;
            }
            else
            {
               return false;
            }
         }
         catch(Exception ex)
         {
            return false;
         }
      }

      private void _btnCapture_Click(object sender, EventArgs e)
      {
         captureCtrl1.TargetFile = DVRfilePath;
         captureCtrl1.TargetFormat = TargetFormatType.DVRTransport;
         captureCtrl1.VideoCompressors.Mpeg4.Selected = true;
         captureCtrl1.SelectedVideoProcessors.Add(captureCtrl1.VideoProcessors.MotionDetection);       

         mtnCllbck = new MtnDtCallback();
         mtnCllbck.theForm = this;
         motion = captureCtrl1.GetSubObject(CaptureObject.SelVideoProcessor) as LMVMtnDetLib.ILMVMtnDet;
         motion.CallbackObj = mtnCllbck;
         motion.MinStillTime = int.Parse(_tbMinStillTime.Text);//1000;
         motion.Interval = int.Parse(_tbInterval.Text);
         motion.AutoStart = false;
         motion.Sensitivity = int.Parse(_tbSensitivity.Text);
         motion.EnableRegion = false;
         captureCtrl1.StartCapture(CaptureMode.VideoAndAudio);
         motion.StartDetection();         
         updatecontrols();

      }
      private void updatecontrols()
      {
         _cbVideoDevices.Enabled = !_cbVideoDevices.Enabled;
         _cbAudioDevices.Enabled = !_cbAudioDevices.Enabled;
         _btnCapture.Enabled = !_btnCapture.Enabled;
         _btnStopCapture.Enabled = !_btnStopCapture.Enabled;
         _tbInterval.Enabled = !_tbInterval.Enabled;
         _tbMinStillTime.Enabled = !_tbMinStillTime.Enabled;
         _tbSensitivity.Enabled = !_tbSensitivity.Enabled;
      }


      private void _cbVideoDevices_SelectedIndexChanged(object sender, EventArgs e)
      {
         captureCtrl1.Preview = false;
         captureCtrl1.VideoDevices[_cbVideoDevices.SelectedIndex].Selected = true;
         captureCtrl1.Preview = true;
      }

      private void _cbAudioDevices_SelectedIndexChanged(object sender, EventArgs e)
      {
         captureCtrl1.Preview = false;
         captureCtrl1.AudioDevices[_cbAudioDevices.SelectedIndex].Selected = true;
         captureCtrl1.Preview = true;
      }

      private void _btnStopCapture_Click(object sender, EventArgs e)
      {
         if (captureCtrl1.State == CaptureState.Running)
         {
            motion.StopDetection();
            captureCtrl1.StopCapture();
            updatecontrols();
         }
      }
   }

}
